@@ -1,13 +1,5 @@
-
 use python::*;
 
-use std::any::type_name;
-
-
-fn type_of<T>(_: T) -> &'static str {
-    type_name::<T>()
-}
-
 fn main() {
     let float_32 = Float::from(123.123f32);
     print(float_32);
@@ -18,6 +10,7 @@ fn main() {
     let float = Float::from(123.123f32);
     print(float);
     print(repr(&float));
+    let string = String::from("asd");
 
     let mut float_list = List::new();
     float_list.append_back(float_32);
@@ -32,5 +25,4 @@ fn main() {
     println!("{:#?}", float_64);
     println!("{:?}", float_64);
     println!("{:#}", float_64);
-
-}
\ No newline at end of file
+}
