@@ -1,5 +1,3 @@
-
-
 #![allow(
     dead_code,
     unused_imports,
@@ -29,55 +27,91 @@ use std::fmt::Result;
 // use python::len;
 // use python::repr;
 
+// the crate name is 'python-objects'
+// because there is another crate out there with `python` name
+// but the lib.rs (library crate of this crate) its called `python`
+// so you can import like this
+extern crate python;
+// actually 'extern crate' is useless
+// just use only 'use python::'
+
+// use everything from python
 use python::*;
 
-
 fn main() {
-    // example of what i want
-
-    let mut python_list =
-        List::from(String::from("123123"));
+    // create a new python list
+    let mut python_list = List::from(String::from("123123"));
+    // at this point the list will look like this
+    // ['1', '2', '3', '1', '2', '3']
 
+    // append an integer
     python_list.append_back(123);
+    // append a rust static string
     python_list.append_front("hello");
     python_list.append_back(123);
-    python_list.append_back(List::from(List::from(String::from("working"))));
+    // append a list
+    python_list.append_back(List::from(String::from("working")));
+    // note that the python list supports another python list inside
+
+    // append a float
     python_list.append_back(123.123);
     python_list.append_back(123.123);
     python_list.append_back(123.123);
+    // append a rust String
     python_list.append_back(String::from("asdasd"));
 
-    python_list.append_back(
-        List::from("something".to_string()));
-    python_list.append_back(
-        _String::from_string(
-            String::from("python string")));
+    python_list.append_back(List::from("something".to_string()));
 
+    // append a python string
+    // note that this _String is from this crate
+    // its the struct that handles the String and &str data types
+    python_list
+        .append_back(_String::from(String::from("python string")));
+
+    // append a python bool
+    // note that Bool is the python struct that handles rust's bool
     python_list.append_back(Bool::new(true));
     python_list.append_back(Bool::new(false));
+    // append a rust bool
     python_list.append_back(false);
 
+    // print just like in python
     print(&python_list);
+
+    // use len just like in python
     print(len(&python_list));
 
 
     // python_list.append_front("salutare");
 
+    // iterate over the list just like in python
+    // there are plans for future to remove the .iter()
+    // so you can use for o in python_list { ... }, just that simple
     for o in python_list.iter() {
         print(o)
     }
 
+    print("\n");
+    print("----");
+    print(python_list.__str__());
+    print("----");
+    print("\n");
 
+    // create a python from parsing a static string
     let list_from_str = "123123".parse::<List>().unwrap();
     print(&list_from_str);
 
+
     let iter = (0..5).into_iter();
     // let list_from_iterator: List = iter.collect();
+
+    // create a python list from rust iterator
     let list_from_iterator = iter.collect::<List>();
     print(&list_from_iterator);
 
 
-
+    print(repr(&python_list));
+    print(repr(&list_from_iterator));
 
     // let oo = Object::Int(Int::new(123));
     // println!("{}", oo);
@@ -85,7 +119,6 @@ fn main() {
     // let oo = Object::Float(Float::new(123.123));
     // println!("{}", oo);
 
-
     // let empty_list = List::new();
     // println!("{}", empty_list);
 
@@ -142,7 +175,6 @@ fn main() {
     // let integer = Int { value: 123i32};
     // let floater = Float { value: 123.123f32};
 
-
     // println!("{}", len(&integer));
     // println!("{}", len(integer));
 }
