@@ -1,8 +1,3 @@
-
-
-
-
-
 use std::fmt::Display;
 use std::fmt::Formatter;
 use std::fmt::Result;
@@ -11,9 +6,11 @@ use crate::_Object;
 
 
 /// Bool structure for True and False
-#[derive(Copy, Clone)]
+#[derive(Copy)]
+#[derive(Clone)]
+#[derive(Default)]
 pub struct Bool {
-    _bool: bool
+    _bool: bool,
 }
 
 impl Bool {
@@ -23,7 +20,7 @@ impl Bool {
     /// let boolean = Bool::new(false)
     pub fn new(_bool: bool) -> Bool {
         Bool {
-            _bool
+            _bool,
         }
     }
 }
@@ -47,7 +44,7 @@ impl _Object for Bool {
 }
 
 impl Display for Bool {
-    fn fmt(&self, f: &mut Formatter<'_>) -> Result {
-        write!(f, "{}", self.__str__())
+    fn fmt(&self, formatter: &mut Formatter<'_>) -> Result {
+        write!(formatter, "{}", self.__str__())
     }
-}
\ No newline at end of file
+}
