@@ -1,12 +1,12 @@
-
 #![doc = include_str!("../docs/python.md")]
 #![doc = include_str!("../docs/python_list/showcase.md")]
-
-#![warn(missing_docs)]
+#![deny(missing_docs)]
+#![deny(dead_code)]
+#![allow(clippy::module_inception)]
+#![allow(clippy::useless_format)]
 
 
-
-mod int;
+mod integer;
 mod float;
 mod string;
 mod character;
@@ -15,9 +15,10 @@ mod dict;
 mod builtins;
 mod boolean;
 mod list;
+mod iterable;
 
 
-pub use int::Int;
+pub use integer::Int;
 pub use float::Float;
 pub use string::_String;
 pub use character::Char;
@@ -25,14 +26,23 @@ pub use object::Object;
 pub use object::_Object;
 pub use boolean::Bool;
 pub use dict::Dict;
+pub use iterable::Iterable;
+
 
 // builtins.rs
+// simple print
 pub use builtins::print;
-pub use builtins::len;
+// print with debug
+pub use builtins::printd;
+// debug print dbg! macro
+pub use builtins::dprint;
 pub use builtins::repr;
 pub use builtins::type_of;
+pub use builtins::len;
+pub use builtins::_str;
+pub use builtins::max;
 
 
 pub use list::List;
 pub use list::Append;
-pub use list::AppendFront;
\ No newline at end of file
+pub use list::AppendFront;
