@@ -1,6 +1,3 @@
-
-
-
 use crate::Object;
 use crate::Int;
 use crate::Float;
@@ -25,17 +22,16 @@ pub trait Append<T>: Sized {
 ///
 /// let mut one_elem = List::new();
 /// one_elem
-///     .append_int(123)
-///     .append_int(123)
-///     .append_int(123)
-///     .append_int(123)
-///     .append_int(123)
-///     .append_int(123)
-///     .append_int(123);
+///     .append_back(123)
+///     .append_back(123)
+///     .append_back(123)
+///     .append_back(123)
+///     .append_back(123)
+///     .append_back(123)
+///     .append_back(123);
 /// println!("{}", one_elem);
 ///
 /// [123, 123, 123, 123, 123, 123, 123]
-///
 impl Append<i32> for List {
     fn append_back(&mut self, _integer: i32) -> &mut Self {
         self._list.push_back(Object::Int(Int::new(_integer)));
@@ -45,14 +41,14 @@ impl Append<i32> for List {
 
 impl Append<Float<f32>> for List {
     fn append_back(&mut self, _float: Float<f32>) -> &mut Self {
-        self._list.push_back(Object::Float32(Float::from(_float)));
+        self._list.push_back(Object::Float32(_float));
         self
     }
 }
 
 impl Append<Float<f64>> for List {
     fn append_back(&mut self, _float: Float<f64>) -> &mut Self {
-        self._list.push_back(Object::Float64(Float::from(_float)));
+        self._list.push_back(Object::Float64(_float));
         self
     }
 }
@@ -60,7 +56,8 @@ impl Append<Float<f64>> for List {
 
 impl Append<&str> for List {
     fn append_back(&mut self, _static_string: &str) -> &mut Self {
-        self._list.push_back(Object::String(_String::from_str(_static_string)));
+        self._list
+            .push_back(Object::String(_String::from(_static_string)));
         self
     }
 }
@@ -68,7 +65,7 @@ impl Append<&str> for List {
 
 impl Append<char> for List {
     fn append_back(&mut self, _char: char) -> &mut Self {
-        self._list.push_back(Object::Char(Char::new(_char)));
+        self._list.push_back(Object::Char(Char::from(_char)));
         self
     }
 }
@@ -83,7 +80,7 @@ impl Append<f32> for List {
 
 impl Append<String> for List {
     fn append_back(&mut self, string: String) -> &mut Self {
-        self._list.push_back(Object::String(_String::from_string(string)));
+        self._list.push_back(Object::String(_String::from(string)));
         self
     }
 }
@@ -96,7 +93,7 @@ impl Append<_String> for List {
 }
 
 impl Append<bool> for List {
-    fn append_back(&mut self, _bool: bool) ->&mut Self {
+    fn append_back(&mut self, _bool: bool) -> &mut Self {
         self._list.push_back(Object::Bool(Bool::new(_bool)));
         self
     }
@@ -104,9 +101,8 @@ impl Append<bool> for List {
 
 
 impl Append<Bool> for List {
-
     #[doc = include_str!("../../docs/python_list/append_pbool.md")]
-    fn append_back(&mut self, _bool: Bool) ->&mut Self {
+    fn append_back(&mut self, _bool: Bool) -> &mut Self {
         self._list.push_back(Object::Bool(_bool));
         self
     }
@@ -117,4 +113,4 @@ impl Append<List> for List {
         self._list.push_back(Object::List(_list));
         self
     }
-}
\ No newline at end of file
+}
