@@ -1,5 +1,3 @@
-
-
 use crate::Object;
 use crate::Int;
 use crate::Float;
@@ -11,7 +9,6 @@ use crate::Bool;
 use super::List;
 
 
-
 /// appends to front of the list
 /// meaning: list.insert(o, item)
 pub trait AppendFront<T>: Sized {
@@ -29,11 +26,8 @@ impl AppendFront<i32> for List {
 
 
 impl AppendFront<&str> for List {
-    fn append_front(
-        &mut self,
-        _static_string: &str
-    ) -> &mut Self {
-        self._list.push_front(Object::String(_String::from_str(_static_string)));
+    fn append_front(&mut self, _str: &str) -> &mut Self {
+        self._list.push_front(Object::String(_String::from(_str)));
         self
     }
 }
@@ -62,7 +56,7 @@ impl AppendFront<f64> for List {
 
 impl AppendFront<String> for List {
     fn append_front(&mut self, string: String) -> &mut Self {
-        self._list.push_front(Object::String(_String::from_string(string)));
+        self._list.push_front(Object::String(_String::from(string)));
         self
     }
 }
@@ -75,7 +69,7 @@ impl AppendFront<_String> for List {
 }
 
 impl AppendFront<bool> for List {
-    fn append_front(&mut self, _bool: bool) ->&mut Self {
+    fn append_front(&mut self, _bool: bool) -> &mut Self {
         self._list.push_front(Object::Bool(Bool::new(_bool)));
         self
     }
@@ -83,9 +77,8 @@ impl AppendFront<bool> for List {
 
 
 impl AppendFront<Bool> for List {
-
     #[doc = include_str!("../../docs/python_list/append_pbool.md")]
-    fn append_front(&mut self, _bool: Bool) ->&mut Self {
+    fn append_front(&mut self, _bool: Bool) -> &mut Self {
         self._list.push_front(Object::Bool(_bool));
         self
     }
@@ -96,4 +89,4 @@ impl AppendFront<List> for List {
         self._list.push_front(Object::List(_list));
         self
     }
-}
\ No newline at end of file
+}
